@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2001 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,8 +11,6 @@
 #
 ##############################################################################
 """ Dublin Core support for content types.
-
-$Id: DublinCore.py 94488 2009-01-03 16:28:03Z yuppie $
 """
 
 from AccessControl.SecurityInfo import ClassSecurityInfo
@@ -22,12 +20,13 @@ from App.class_init import InitializeClass
 from App.special_dtml import DTMLFile
 from DateTime.DateTime import DateTime
 from OFS.PropertyManager import PropertyManager
+from zope.component import queryUtility
 from zope.interface import implements
 
 from Products.CMFCore.interfaces import ICatalogableDublinCore
 from Products.CMFCore.interfaces import IDublinCore
+from Products.CMFCore.interfaces import IMetadataTool
 from Products.CMFCore.interfaces import IMutableDublinCore
-from Products.CMFCore.utils import getToolByName
 from Products.CMFDefault.permissions import ModifyPortalContent
 from Products.CMFDefault.permissions import View
 from Products.CMFDefault.utils import _dtmldir
@@ -158,11 +157,10 @@ class DefaultDublinCoreImpl( PropertyManager ):
         return self.description
 
     security.declareProtected(View, 'Publisher')
-    def Publisher( self ):
+    def Publisher(self):
         """ Dublin Core Publisher element - resource publisher.
         """
-        tool = getToolByName(self, 'portal_metadata', None)
-
+        tool = queryUtility(IMetadataTool)
         if tool is not None:
             return tool.getPublisher()
 
@@ -336,7 +334,7 @@ class DefaultDublinCoreImpl( PropertyManager ):
         hdrlist.append( ( 'Contributors', '; '.join( self.Contributors() ) ) )
         hdrlist.append( ( 'Effective_date', self.EffectiveDate() ) )
         hdrlist.append( ( 'Expiration_date', self.ExpirationDate() ) )
-        hdrlist.append( ( 'Type', self.Type() ) )
+        hdrlist.append( ( 'Type', self.getPortalTypeName() or 'Unknown' ) )
         hdrlist.append( ( 'Format', self.Format() ) )
         hdrlist.append( ( 'Language', self.Language() ) )
         hdrlist.append( ( 'Rights', self.Rights() ) )
@@ -416,21 +414,20 @@ class DefaultDublinCoreImpl( PropertyManager ):
         self.rights = rights
 
     #
-    #  Management tab methods
+    #   Utility methods
     #
-
-    security.declarePrivate( '_editMetadata' )
-    def _editMetadata( self
-                     , title=_marker
-                     , subject=_marker
-                     , description=_marker
-                     , contributors=_marker
-                     , effective_date=_marker
-                     , expiration_date=_marker
-                     , format=_marker
-                     , language=_marker
-                     , rights=_marker
-                     ):
+    security.declarePrivate('_editMetadata')
+    def _editMetadata(self,
+                      title=_marker,
+                      subject=_marker,
+                      description=_marker,
+                      contributors=_marker,
+                      effective_date=_marker,
+                      expiration_date=_marker,
+                      format=_marker,
+                      language=_marker,
+                      rights=_marker,
+                      **kw):
         """ Update the editable metadata for this resource.
         """
         if title is not _marker:
@@ -452,6 +449,9 @@ class DefaultDublinCoreImpl( PropertyManager ):
         if rights is not _marker:
             self.setRights( rights )
 
+    #
+    #   ZMI methods
+    #
     security.declareProtected(ModifyPortalContent, 'manage_metadata')
     manage_metadata = DTMLFile( 'zmi_metadata', _dtmldir )
 
