@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2001 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -13,7 +13,7 @@
 """ This module implements a portal-managed Image class. It is based on
 Zope's built-in Image object.
 
-$Id: Image.py 105926 2009-11-20 20:52:23Z MatthewWilkes $
+$Id: Image.py 122271 2011-07-17 18:49:11Z hannosch $
 """
 
 from AccessControl.SecurityInfo import ClassSecurityInfo
@@ -98,6 +98,7 @@ class Image(PortalContent, OFS.Image.Image, DefaultDublinCoreImpl):
 
     effective_date = expiration_date = None
     icon = PortalContent.icon
+    id = None
 
     manage_options = manage_options
 
@@ -132,12 +133,6 @@ class Image(PortalContent, OFS.Image.Image, DefaultDublinCoreImpl):
                                , contributors, effective_date, expiration_date
                                , format, language, rights )
 
-    # For old instances where bases had OFS.Image.Image first,
-    # the id was actually stored in __name__.
-    # getId() will do the correct thing here, as id() is callable
-    def id(self):
-        return self.__name__
-
     security.declareProtected(View, 'SearchableText')
     def SearchableText(self):
         """
